#
# spec file for package nss-pam-ldapd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_pam_moduledir: %define _pam_moduledir /%{_lib}/security}

Name:           nss-pam-ldapd
Version:        0.9.12
Release:        1.9
Summary:        NSS module and daemon for using LDAP as a naming service
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/LDAP/Clients
URL:            http://arthurdejong.org/nss-ldapd/
Source:         https://arthurdejong.org/nss-pam-ldapd/nss-pam-ldapd-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        nslcd.service
Source100:      nss-pam-ldapd-rpmlintrc
BuildRequires:  automake
BuildRequires:  krb5-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  systemd-rpm-macros
Requires(pre):  shadow
Conflicts:      nss_ldap
Conflicts:      pam_ldap
Obsoletes:      nss-ldapd < %{version}-%{release}
Provides:       nss-ldapd = %{version}-%{release}

%description
This is nss-pam-ldapd which provides a Name Service Switch (NSS)
module that allows your LDAP server to provide user account, group,
host name, alias, netgroup, and basically any other information that
you would normally get from %{_sysconfdir} flat files or NIS. It also provides a
Pluggable Authentication Module (PAM) to do authentication to an LDAP
server.

This is implemented using thin NSS and PAM modules which delegate to a
dedicated service (nslcd) that queries the LDAP server with persistent
connections, authentication, attribute translation, etc.

%prep
%setup -q

%build
autoreconf
export CPPFLAGS="-I/usr/include/sasl"
%configure --libdir=/%{_lib} \
	    --with-pam-seclib-dir=%{_pam_moduledir} \
		--disable-utils
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
mkdir -p %{buildroot}/%{_unitdir}/
install -p -m644 %{SOURCE2} %{buildroot}/%{_unitdir}/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcnslcd

%pre
# creating groupd and user nslcd
%{_bindir}/getent group nslcd >/dev/null || %{_sbindir}/groupadd -r nslcd
%{_bindir}/getent passwd nslcd >/dev/null || \
  %{_sbindir}/useradd -r -g nslcd -d / -s /sbin/nologin \
  -c "nslcd ldap user" nslcd
%service_add_pre nslcd.service

%post
/sbin/ldconfig
%service_add_post nslcd.service

%preun
%service_del_preun nslcd.service

%postun
/sbin/ldconfig
%service_del_postun nslcd.service

%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog NEWS README
/%{_lib}/libnss_ldap.so.2
%{_pam_moduledir}/pam_ldap.so
%{_mandir}/man?/*
%config(noreplace) %attr(640,root,root) %{_sysconfdir}/nslcd.conf
/%{_unitdir}/nslcd.service
%{_sbindir}/nslcd
%{_sbindir}/rcnslcd

%changelog
* Sat Nov 20 2021 Michael Ströder <michael@stroeder.com>
- Update to 0.9.12
  * allow explicitly configuring an empty search base (for LDAP servers that support that)
  * support LDAP attributes with minus characters in attribute mapping expressions
  * add tls_reqsan, tls_crlfile and tls_crlcheck options
  * support generating ldaps:// URIs from DNS SRV records for port 389 by using DNSLDAPS in the uri option
  * prefer the first URI listed in nslcd.conf after reconnecting after idle_timelimit
  * fix handling of pam_authc_ppolicy no
  * fix debug logging of ldap timeout values
  * documentation improvements
  * add pam_authc_ppolicy support to pynslcd
  * fix Python 3 compatibility in chsh.ldap
  * fix for running pynslcd without the uid option
  * partial support for running tests with slapd 2.5
  * miscellaneous test suite improvements
  * test suite fixes for Solaris
* Mon Oct 18 2021 Michael Ströder <michael@stroeder.com>
- Define macro _pam_moduledir if not set to fix builds for Leap and SLE
* Mon Oct 11 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * nslcd.service
* Tue Sep 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_pam_moduledir instead of hardcoding %%{_lib}/security
  (boo#1191050).
* Mon Oct  7 2019 mvetter@suse.com
- Update to 0.9.11:
  * add support for Python 3 in pynslcd and utilities
  * fix crash in chsh.ldap (thanks Mizunashi Mana)
  * test suite improvements
* Mon Sep  3 2018 mvetter@suse.com
- Update to 0.9.10:
  * add FreeBSD netgroup support (thanks HWLin and Mango Yen)
  * make password expiry messages correct and consistent (thanks Têko Mihinto)
  * add domain variable for use in pam_authz_search
  * allow logging longer lines
  * create nslcd socket after dropping privileges to avoid slow start-ups
* Fri Mar  9 2018 dimstar@opensuse.org
- Add the conflicts from the mainpackage also to the baselibs.conf
  generated ones: the -32bit packages conflict the same way.
- Modernize spec file by calling spec-cleaner.
* Sun Feb 18 2018 mvetter@suse.com
- Update to 0.9.9:
  * support spaces in attribute mapping expressions
  * allow parsing longer lines in the configuration file
  * allow for longer host names
* Tue Jun 27 2017 mvetter@suse.com
- Update to 0.9.8:
  * add a pam_authc_search option that can be used to configure the search operation that is performed after authentication
  * add nss_uid_offset and nss_gid_offset options that can be used to change returned numeric user and group ids from LDAP (thanks Seth Wright)
  * do not retry failed user password on second LDAP server
  * fix a crash in the PAM module on FreeBSD when showing password expiration messages
  * the validnames option now also applies to shadow lookups
  * support ethernet addresses in LDAP in compact and long formats
  * improvements to getent.ldap command (a few minor bug fixes and preparations for Python 3 support)
  * log entries and lookups failing nss_min_uid at debug level
  * improvements to the test suite (including tests for getent.ldap)
* Mon Mar 13 2017 ailin.nemui@gmail.com
- Drop SysV support / %%insserv_cleanup, it breaks package on TW
* Fri Sep  9 2016 hguo@suse.com
- Upgrade to 0.9.7 with accumulated bug fixes.
* Tue Jun 21 2016 jengelh@inai.de
- Do not suppress errors from useradd/groupadd.
  Reduce dependencies for it.
* Fri Jun 17 2016 mvetter@suse.com
- Explicityly disable nslcd-utils otherwise it will auto-enable them
  if python is present. This can lead to different builds depending on
  environment. And creation of files %%{_datadir}/nslcd-utils/*.py?
  %%{_bindir}/chsh.ldap, %%{_bindir}/getent.ldap
* Thu Jun 16 2016 mvetter@suse.com
- Package all installed files
* Thu Jun 16 2016 mvetter@suse.com
- Create user and group nslcd.
- Remove nslcd-user-conf.dif:
  It shouldn't be run as root.
* Wed Jun 15 2016 jengelh@inai.de
- Drop %%clean section and authors list.
  %%doc is already implicit for manpages.
* Mon Sep 14 2015 hguo@suse.com
- Upgrade source from upstream release 0.9.5 to 0.9.6 with accumulated
  bug fixes.
- Install rc-link.
* Sun Apr  5 2015 ailin.nemui@gmail.com
- new upload to the build service after discontinuation in opensuse
  12.3
